# tech_inspection_service_client
Сервис получения информации об операторах и точках тех обслуживания

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0
- Build date: 2021-03-02T13:38:01.485Z[GMT]
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import tech_inspection_service_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import tech_inspection_service_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import tech_inspection_service_client
from tech_inspection_service_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to BASE_URL
# See configuration.py for a list of all supported configuration parameters.
configuration = tech_inspection_service_client.Configuration(
    host = "BASE_URL"
)



# Enter a context with an instance of the API client
with tech_inspection_service_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tech_inspection_service_client.OperatorsApi(api_client)
    tech_inspection_operator_query = tech_inspection_service_client.TechInspectionOperatorQuery() # TechInspectionOperatorQuery | New operator (optional)

    try:
        # Add new operator
        api_response = api_instance.add_operator(tech_inspection_operator_query=tech_inspection_operator_query)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling OperatorsApi->add_operator: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *BASE_URL*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OperatorsApi* | [**add_operator**](docs/OperatorsApi.md#add_operator) | **POST** /v1/techOperators | Add new operator
*OperatorsApi* | [**get_operator_by_id**](docs/OperatorsApi.md#get_operator_by_id) | **GET** /v1/techOperators/{operatorId} | Get operator by operatorId
*OperatorsApi* | [**remove_operator**](docs/OperatorsApi.md#remove_operator) | **DELETE** /v1/techOperators/{operatorId} | Remove operator
*OperatorsApi* | [**update_operator**](docs/OperatorsApi.md#update_operator) | **PUT** /v1/techOperators | Update operator info
*PointsApi* | [**add_point**](docs/PointsApi.md#add_point) | **POST** /v1/techPoints/{operatorId} | Add new point to operator
*PointsApi* | [**get_point_by_id**](docs/PointsApi.md#get_point_by_id) | **GET** /v1/techPoints/{pointId} | Get point by pointId
*PointsApi* | [**get_points_by_coordinates**](docs/PointsApi.md#get_points_by_coordinates) | **GET** /v1/techPoints/byCoordinates | Get points by location route
*PointsApi* | [**get_points_by_location_route**](docs/PointsApi.md#get_points_by_location_route) | **GET** /v1/techPoints/byRoute | Get points by location route
*PointsApi* | [**remove_point**](docs/PointsApi.md#remove_point) | **DELETE** /v1/techPoints/{pointId} | Remove point
*PointsApi* | [**update_point**](docs/PointsApi.md#update_point) | **PUT** /v1/techPoints | Update point info


## Documentation For Models

 - [Error](docs/Error.md)
 - [ErrorModel](docs/ErrorModel.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [TechInspectionOperatorQuery](docs/TechInspectionOperatorQuery.md)
 - [TechInspectionOperatorStatus](docs/TechInspectionOperatorStatus.md)
 - [TechInspectionPointQuery](docs/TechInspectionPointQuery.md)
 - [TechInspectionPointQueryQueryResult](docs/TechInspectionPointQueryQueryResult.md)
 - [TechInspectionPointStatus](docs/TechInspectionPointStatus.md)


## Documentation For Authorization


## openIdConnect

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




